# There is a plus on the end for unreleased versions, not for released versions
%global instdir %{name}-%{version}+

%bcond_with extracheck
%bcond_with pcre
%bcond_with gtk2

# This package uses toplevel ASMs which are incompatible with LTO
%global _lto_cflags %{nil}

%define ver	2.49.93
%define date	20240901

Name:		clisp
Summary:	ANSI Common Lisp implementation
Epoch:		1
Version:	%{ver}
# The project as a whole is GPL-2.0-or-later.  Exceptions:
# - Some documentation is dual-licensed as GPL-2.0-or-later OR GFDL-1.2-or-later
# - src/gllib is LGPL-2.1-or-later
# - src/socket.d and modules/clx/mit-clx/doc.lisp are HPND
# - src/xthread.d and modules/asdf/asdf.lisp are X11
License:	GPL-2.0-or-later AND (GPL-2.0-or-later OR GFDL-1.2-or-later) AND LGPL-2.1-or-later AND HPND AND X11
Release:	%mkrel 0.git%{date}.1
URL:		http://www.clisp.org/
Group:		Development/Other
Source0:	https://gitlab.com/gnu-clisp/clisp/-/archive/master/clisp-master.tar.bz2
# Upstream dropped this file from the distribution
Source1:	https://gitlab.com/sam-s/clhs/-/raw/master/clhs.el
# Updated translations
Source2:	http://translationproject.org/latest/clisp/sv.po
Source3:	http://translationproject.org/latest/clisp/de.po
# https://sourceforge.net/p/clisp/patches/35/
Patch0:		%{name}-db.patch
# https://sourceforge.net/p/clisp/patches/32/
Patch1:		%{name}-format.patch
# The combination of register and volatile is nonsensical
Patch2:		%{name}-register-volatile.patch
# A test that writes to /dev/pts/0 succeeds or fails apparently at random.
# I can only guess that /dev/pts/0 may or may not be what the test expects.
# Perhaps we are racing with something else that allocates a pty.  Disable
# the test for now.
Patch3:		%{name}-pts-access.patch
# Fix HAVE_DB_STAT_ACCEPT_TXN test in the Berkeley DB module
# https://gitlab.com/gnu-clisp/clisp/-/merge_requests/8
Patch4:		%{name}-c99.patch
# Fix mismatched pointer types in the Berkeley DB module
# https://gitlab.com/gnu-clisp/clisp/-/merge_requests/9
Patch5:		%{name}-bdb-mismatched-pointer.patch
# Fix the new-clx build, which was broken by a recent gnulib update
# https://gitlab.com/gnu-clisp/clisp/-/merge_requests/10
Patch6:		%{name}-new-clx.patch
# Do not call the deprecated siginterrupt function
Patch7:		%{name}-siginterrupt.patch
# Adapt to changes in pari 2.17
Patch8:		%{name}-pari.patch

# Work around a problem inlining a function on ppc64le
# See https://bugzilla.redhat.com/show_bug.cgi?id=2049371
Patch100:	%{name}-no-inline.patch

BuildRequires:	pkgconfig(dbus-1)
BuildRequires:	pkgconfig(ice)
BuildRequires:	diffutils
BuildRequires:	emacs
BuildRequires:	fcgi-devel
BuildRequires:	ffcall-devel
BuildRequires:	gcc
BuildRequires:	gdbm-devel
BuildRequires:	gettext-devel
BuildRequires:	ghostscript
BuildRequires:	locales-en
BuildRequires:	locales-fr
BuildRequires:	locales-ja
BuildRequires:	locales-zh
BuildRequires:	groff
%if %{with gtk2}
BuildRequires:	gtk2-devel
BuildRequires:	pkgconfig(libglade-2.0)
%endif
%if %{with pcre}
BuildRequires:	pkgconfig(libpcre)
%endif
BuildRequires:	pkgconfig(xaw7)
BuildRequires:	pkgconfig(xft)

BuildRequires:	libdb-devel
BuildRequires:	%{_lib}sigsegv-devel
BuildRequires:	unistring-devel
BuildRequires:	pkgconfig(libxcrypt)
BuildRequires:	pkgconfig(ncursesw)
BuildRequires:	pkgconfig(sm)
BuildRequires:	pkgconfig(x11)
BuildRequires:	pkgconfig(xau)
BuildRequires:	pkgconfig(xext)
BuildRequires:	pkgconfig(xpm)
BuildRequires:	imake
BuildRequires:	make
%if 0
BuildRequires:	pari-devel
%endif
BuildRequires:	postgresql-devel
BuildRequires:	pkgconfig(readline)
BuildRequires:	pkgconfig(zlib)
Provides:	ansi-cl

# clisp contains a copy of gnulib, which has been granted a bundling exception:
# https://fedoraproject.org/wiki/Packaging:No_Bundled_Libraries#Packages_granted_exceptions
Provides:	bundled(gnulib)

%description
ANSI Common Lisp is a high-level, general-purpose programming
language.  GNU CLISP is a Common Lisp implementation by Bruno Haible
of Karlsruhe University and Michael Stoll of Munich University, both
in Germany.  It mostly supports the Lisp described in the ANSI Common
Lisp standard.  It runs on most Unix workstations (GNU/Linux, FreeBSD,
NetBSD, OpenBSD, Solaris, Tru64, HP-UX, BeOS, NeXTstep, IRIX, AIX and
others) and on other systems (Windows NT/2000/XP, Windows 95/98/ME)
and needs only 4 MiB of RAM.

It is Free Software and may be distributed under the terms of GNU GPL,
while it is possible to distribute commercial proprietary applications
compiled with GNU CLISP.

The user interface comes in English, German, French, Spanish, Dutch,
Russian and Danish, and can be changed at run time.  GNU CLISP
includes an interpreter, a compiler, a debugger, CLOS, MOP, a foreign
language interface, sockets, i18n, fast bignums and more.  An X11
interface is available through CLX, Garnet, CLUE/CLIO.  GNU CLISP runs
Maxima, ACL2 and many other Common Lisp packages.


%package	devel
Summary:	Development files for CLISP
Group:		Development/Other
Provides:	%{name}-static = %{version}-%{release} 
Requires:	%{name} = %{epoch}:%{version}-%{release}
Conflicts:	%{name} < 1:2.49.92

%description	devel
Files necessary for linking CLISP programs.


%prep
%setup -qn %{name}-master
%autopatch -M99 -p0
%ifarch %{power64}
%autopatch 100 -p0
%endif
cp -p %{SOURCE1} emacs
cp -p %{SOURCE2} %{SOURCE3} src/po

# We only link against libraries in system directories, so we need -L dir in
# place of -Wl,-rpath -Wl,dir
cp -p src/build-aux/config.rpath config.rpath.orig
sed -i -e 's/${wl}-rpath ${wl}/-L/g' src/build-aux/config.rpath

# Fix modules that need access to symbols in libgnu.a
sed -i 's/\(${GLLIB_A}\) \(${LIBS}\)/-Wl,--whole-archive \1 -Wl,--no-whole-archive \2 -ldl/' src/makemake.in

# When building modules, put -Wl,--as-needed before the libraries to link
sed -i "s/CC='\${CC}'/CC='\${CC} -Wl,--as-needed'/" src/makemake.in

# Enable firefox to be the default browser for displaying documentation
sed -i 's/;; \((setq \*browser\* .*)\)/\1/' src/cfgunix.lisp

# Unpack the CLX manual
tar -C modules/clx -xzf modules/clx/clx-manual.tar.gz
chmod -R go+r modules/clx/clx-manual
chmod a-x modules/clx/clx-manual/html/doc-index.cgi

# On some koji builders, something is already listening on port 9090, which
# causes a spurious test failure.  Change to port 9096 for the test.
sed -i 's/9090/9096/g' tests/socket.tst

%build
# Do not need to specify base modules: i18n, readline, regexp, syscalls.
# The dirkey module currently can only be built on Windows/Cygwin/MinGW.
# The editor module is not in good enough shape to use.
# The matlab, netica, and oracle modules require proprietary code to build.
# The queens module is intended as an example only, not for actual use.
./configure --prefix=%{_prefix} \
	    --libdir=%{_libdir} \
	    --mandir=%{_mandir} \
	    --infodir=%{_infodir} \
	    --docdir=%{_pkgdocdir} \
	    --fsstnd=redhat \
	    --with-module=asdf \
	    --with-module=berkeley-db \
	    --with-module=bindings/glibc \
	    --with-module=clx/new-clx \
	    --with-module=dbus \
	    --with-module=fastcgi \
	    --with-module=gdbm \
%if %{with gtk2}
	    --with-module=gtk2 \
%endif
%if 0
	    --with-module=libsvm \
	    --with-module=pari \
%endif
%if %{with pcre}
	    --with-module=pcre \
%endif
	    --with-module=postgresql \
	    --with-module=rawsock \
	    --with-module=zlib \
	    --with-libreadline-prefix=$PWD/readline \
	    --with-ffcall \
%if %{with extracheck}
	    --cbcx \
%endif
	    build \
%if 0
	    CPPFLAGS="-I/usr/include/libsvm" \
%endif
	    CFLAGS="%{optflags} -Wa,--noexecstack" \
	    LDFLAGS="%(echo "%{ldflags}" | sed "s/-Wl,--no-undefined/-Wl,-z,noexecstack/")"

cd build
# Workaround libtool reordering -Wl,--as-needed after all the libraries.
sed -i 's|CC="\(.*g..\)"|CC="\1 -Wl,--as-needed"|' libtool
make
cd -

%install
make -C build DESTDIR=%{buildroot} install
cp -a build/full %{buildroot}%{_libdir}/%{instdir}
rm -f %{buildroot}%{_pkgdocdir}/doc/clisp.{dvi,1,ps}
rm -f %{buildroot}%{_pkgdocdir}/{COPYRIGHT,GNU-GPL}
cp -p doc/mop-spec.pdf %{buildroot}%{_pkgdocdir}/doc
cp -p doc/*.png %{buildroot}%{_pkgdocdir}/doc
cp -p doc/Why-CLISP* %{buildroot}%{_pkgdocdir}/doc
cp -p doc/regexp.html %{buildroot}%{_pkgdocdir}/doc
find %{buildroot}%{_libdir} -name '*.dvi' -exec rm -f {} \+
%find_lang %{name}
%find_lang %{name}low
cat %{name}low.lang >> %{name}.lang

# Compile the Emacs interface
pushd %{buildroot}%{_datadir}/emacs/site-lisp
%{_emacs_bytecompile} *.el
popd

# Put back the original config.rpath
cp -p config.rpath.orig %{buildroot}%{_libdir}/%{instdir}/build-aux/config.rpath

# Fix a missing executable bit
chmod a+x %{buildroot}%{_libdir}/%{instdir}/build-aux/depcomp

# Fix paths in the Makefiles
for mk in $(find %{buildroot}%{_libdir} -name Makefile); do
  sed -e "s,$PWD/modules,%{_libdir}/%{instdir}," \
      -e "s,$PWD/build/clisp,%{_bindir}/clisp," \
      -e "s,$PWD/build/linkkit,%{_libdir}/%{instdir}/linkkit," \
      -i $mk
done
for mk in %{buildroot}%{_libdir}/%{instdir}/{base,full}/makevars; do
  sed -e "s, -I$PWD[^']*,," \
      -e "s,%{_libdir}/lib\([[:alnum:]]*\)\.so,-l\1,g" \
      -i $mk
done

# Install config.h, which is needed in some cases
for dir in %{buildroot}%{_libdir}/%{instdir}/*; do
  cp -p build/$(basename $dir)/config.h $dir || :
done
cp -p build/config.h %{buildroot}%{_libdir}/%{instdir}
cp -p build/clx/new-clx/config.h \
   %{buildroot}%{_libdir}/%{instdir}/clx/new-clx

# Fix broken symlinks in the full set
pushd %{buildroot}%{_libdir}/%{instdir}/full
for obj in bogomips calls gettext readline regexi; do
  rm -f ${obj}.o
  ln -s ../base/${obj}.o ${obj}.o
done
for obj in libgnu libnoreadline lisp; do
  rm -f ${obj}.a
  ln -s ../base/${obj}.a ${obj}.a
done
for obj in fastcgi fastcgi_wrappers; do
  rm -f ${obj}.o
  ln -s ../fastcgi/${obj}.o ${obj}.o
done
%if 0
for obj in cpari pari; do
  rm -f ${obj}.o
  ln -s ../pari/${obj}.o ${obj}.o
done
%endif
rm -f bdb.o
ln -s ../berkeley-db/bdb.o bdb.o
rm -f clx.o
ln -s ../clx/new-clx/clx.o clx.o
%if %{with pcre}
rm -f cpcre.o
ln -s ../pcre/cpcre.o cpcre.o
%endif
rm -f dbus.o
ln -s ../dbus/dbus.o dbus.o
rm -f gdbm.o
ln -s ../gdbm/gdbm.o gdbm.o
%if %{with gtk2}
rm -f gtk.o
ln -s ../gtk2/gtk.o gtk.o
%endif
%if 0
rm -f libsvm.o
ln -s ../libsvm/libsvm.o libsvm.o
%endif
rm -f linux.o
ln -s ../bindings/glibc/linux.o linux.o
rm -f postgresql.o
ln -s ../postgresql/postgresql.o postgresql.o
rm -f rawsock.o
ln -s ../rawsock/rawsock.o rawsock.o
rm -f zlib.o
ln -s ../zlib/zlib.o zlib.o
popd

# Help the debuginfo generator
ln -s ../../src/modules.c build/base/modules.c
ln -s ../../src/modules.c build/full/modules.c

%files -f %{name}.lang
%license COPYRIGHT GNU-GPL
%{_bindir}/%{name}
%{_mandir}/man1/%{name}.1*
%{_pkgdocdir}/
%dir %{_libdir}/%{instdir}/
%dir %{_libdir}/%{instdir}/asdf/
%{_libdir}/%{instdir}/asdf/asdf.fas
%dir %{_libdir}/%{instdir}/base/
%{_libdir}/%{instdir}/base/lispinit.mem
%{_libdir}/%{instdir}/base/lisp.run
%dir %{_libdir}/%{instdir}/berkeley-db/
%{_libdir}/%{instdir}/berkeley-db/*.fas
%{_libdir}/%{instdir}/berkeley-db/preload.lisp
%dir %{_libdir}/%{instdir}/bindings/
%dir %{_libdir}/%{instdir}/bindings/glibc/
%{_libdir}/%{instdir}/bindings/glibc/*.fas
%dir %{_libdir}/%{instdir}/clx/
%dir %{_libdir}/%{instdir}/clx/new-clx/
%{_libdir}/%{instdir}/clx/new-clx/*.fas
%{_libdir}/%{instdir}/clx/new-clx/clx-preload.lisp
%{_libdir}/%{instdir}/data/
%dir %{_libdir}/%{instdir}/dbus/
%{_libdir}/%{instdir}/dbus/*.fas
%{_libdir}/%{instdir}/dynmod/
%dir %{_libdir}/%{instdir}/fastcgi/
%{_libdir}/%{instdir}/fastcgi/*.fas
%dir %{_libdir}/%{instdir}/full/
%{_libdir}/%{instdir}/full/lispinit.mem
%{_libdir}/%{instdir}/full/lisp.run
%dir %{_libdir}/%{instdir}/gdbm/
%{_libdir}/%{instdir}/gdbm/*.fas
%{_libdir}/%{instdir}/gdbm/preload.lisp
%if %{with gtk2}
%dir %{_libdir}/%{instdir}/gtk2/
%{_libdir}/%{instdir}/gtk2/*.fas
%{_libdir}/%{instdir}/gtk2/preload.lisp
%endif
%if %{with pcre}
%dir %{_libdir}/%{instdir}/pcre/
%{_libdir}/%{instdir}/pcre/*.fas
%{_libdir}/%{instdir}/pcre/preload.lisp
%endif
%if 0
%dir %{_libdir}/%{instdir}/libsvm/
%{_libdir}/%{instdir}/libsvm/*.fas
%{_libdir}/%{instdir}/libsvm/preload.lisp
%dir %{_libdir}/%{instdir}/pari/
%{_libdir}/%{instdir}/pari/*.fas
%{_libdir}/%{instdir}/pari/preload.lisp
%endif
%dir %{_libdir}/%{instdir}/postgresql/
%{_libdir}/%{instdir}/postgresql/*.fas
%dir %{_libdir}/%{instdir}/rawsock/
%{_libdir}/%{instdir}/rawsock/*.fas
%{_libdir}/%{instdir}/rawsock/preload.lisp
%dir %{_libdir}/%{instdir}/zlib/
%{_libdir}/%{instdir}/zlib/*.fas
%{_datadir}/emacs/site-lisp/*
%{_datadir}/vim/vimfiles/after/syntax/*

%files devel
%doc modules/clx/clx-manual
%{_bindir}/%{name}-link
%{_mandir}/man1/%{name}-link.1*
%{_libdir}/%{instdir}/asdf/Makefile
%{_libdir}/%{instdir}/asdf/*.lisp
%{_libdir}/%{instdir}/asdf/*.sh
%{_libdir}/%{instdir}/base/*.a
%{_libdir}/%{instdir}/base/*.h
%{_libdir}/%{instdir}/base/*.o
%{_libdir}/%{instdir}/base/makevars
%{_libdir}/%{instdir}/berkeley-db/Makefile
%{_libdir}/%{instdir}/berkeley-db/*.h
%{_libdir}/%{instdir}/berkeley-db/dbi.lisp
%{_libdir}/%{instdir}/berkeley-db/*.o
%{_libdir}/%{instdir}/berkeley-db/*.sh
%{_libdir}/%{instdir}/bindings/glibc/Makefile
%{_libdir}/%{instdir}/bindings/glibc/*.lisp
%{_libdir}/%{instdir}/bindings/glibc/*.o
%{_libdir}/%{instdir}/bindings/glibc/*.sh
%{_libdir}/%{instdir}/build-aux/
%{_libdir}/%{instdir}/clx/new-clx/demos/
%{_libdir}/%{instdir}/clx/new-clx/README
%{_libdir}/%{instdir}/clx/new-clx/Makefile
%{_libdir}/%{instdir}/clx/new-clx/*.h
%{_libdir}/%{instdir}/clx/new-clx/clx.lisp
%{_libdir}/%{instdir}/clx/new-clx/image.lisp
%{_libdir}/%{instdir}/clx/new-clx/resource.lisp
%{_libdir}/%{instdir}/clx/new-clx/*.o
%{_libdir}/%{instdir}/clx/new-clx/*.sh
%{_libdir}/%{instdir}/config.h
%{_libdir}/%{instdir}/dbus/Makefile
%{_libdir}/%{instdir}/dbus/*.h
%{_libdir}/%{instdir}/dbus/*.lisp
%{_libdir}/%{instdir}/dbus/*.o
%{_libdir}/%{instdir}/dbus/*.sh
%{_libdir}/%{instdir}/fastcgi/README
%{_libdir}/%{instdir}/fastcgi/Makefile
%{_libdir}/%{instdir}/fastcgi/*.h
%{_libdir}/%{instdir}/fastcgi/*.lisp
%{_libdir}/%{instdir}/fastcgi/*.o
%{_libdir}/%{instdir}/fastcgi/*.sh
%{_libdir}/%{instdir}/full/*.a
%{_libdir}/%{instdir}/full/*.h
%{_libdir}/%{instdir}/full/*.o
%{_libdir}/%{instdir}/full/makevars
%{_libdir}/%{instdir}/gdbm/Makefile
%{_libdir}/%{instdir}/gdbm/*.h
%{_libdir}/%{instdir}/gdbm/gdbm.lisp
%{_libdir}/%{instdir}/gdbm/*.o
%{_libdir}/%{instdir}/gdbm/*.sh
%if %{with gtk2}
%{_libdir}/%{instdir}/gtk2/Makefile
%{_libdir}/%{instdir}/gtk2/*.cfg
%{_libdir}/%{instdir}/gtk2/*.glade
%{_libdir}/%{instdir}/gtk2/*.h
%{_libdir}/%{instdir}/gtk2/gtk.lisp
%{_libdir}/%{instdir}/gtk2/*.o
%{_libdir}/%{instdir}/gtk2/*.sh
%endif
%if 0
%{_libdir}/%{instdir}/libsvm/README
%{_libdir}/%{instdir}/libsvm/Makefile
%{_libdir}/%{instdir}/libsvm/*.h
%{_libdir}/%{instdir}/libsvm/libsvm.lisp
%{_libdir}/%{instdir}/libsvm/*.o
%{_libdir}/%{instdir}/libsvm/*.sh
%endif
%{_libdir}/%{instdir}/linkkit/
%if 0
%{_libdir}/%{instdir}/pari/README
%{_libdir}/%{instdir}/pari/Makefile
%{_libdir}/%{instdir}/pari/*.h
%{_libdir}/%{instdir}/pari/desc2lisp.lisp
%{_libdir}/%{instdir}/pari/pari.lisp
%{_libdir}/%{instdir}/pari/*.o
%{_libdir}/%{instdir}/pari/*.sh
%endif
%if %{with pcre}
%{_libdir}/%{instdir}/pcre/Makefile
%{_libdir}/%{instdir}/pcre/*.h
%{_libdir}/%{instdir}/pcre/*.lisp
%{_libdir}/%{instdir}/pcre/*.o
%{_libdir}/%{instdir}/pcre/*.sh
%endif
%{_libdir}/%{instdir}/postgresql/README
%{_libdir}/%{instdir}/postgresql/Makefile
%{_libdir}/%{instdir}/postgresql/*.h
%{_libdir}/%{instdir}/postgresql/*.lisp
%{_libdir}/%{instdir}/postgresql/*.o
%{_libdir}/%{instdir}/postgresql/*.sh
%{_libdir}/%{instdir}/rawsock/demos/
%{_libdir}/%{instdir}/rawsock/Makefile
%{_libdir}/%{instdir}/rawsock/*.h
%{_libdir}/%{instdir}/rawsock/sock.lisp
%{_libdir}/%{instdir}/rawsock/*.o
%{_libdir}/%{instdir}/rawsock/*.sh
%{_libdir}/%{instdir}/zlib/Makefile
%{_libdir}/%{instdir}/zlib/*.h
%{_libdir}/%{instdir}/zlib/*.lisp
%{_libdir}/%{instdir}/zlib/*.o
%{_libdir}/%{instdir}/zlib/*.sh
%{_datadir}/aclocal/%{name}.m4


%changelog
* Tue Oct 15 2024 ns80 <ns80> 1:2.49.93-0.git20240901.1.mga10
+ Revision: 2106992
- sync with Fedora to try to fix building with GCC 14

* Sun Apr 16 2023 daviddavid <daviddavid> 1:2.49.92-7.mga9
+ Revision: 1953164
- disable old pcre support in Mageia 9 (mga#31791)

* Thu Jan 12 2023 daviddavid <daviddavid> 1:2.49.92-6.mga9
+ Revision: 1932545
- rebuild for new libunistring 1.1

* Wed Mar 30 2022 umeabot <umeabot> 1:2.49.92-5.mga9
+ Revision: 1835271
- Mageia 9 Mass Rebuild

* Tue Feb 18 2020 umeabot <umeabot> 1:2.49.92-4.mga8
+ Revision: 1542090
- Mageia 8 Mass Rebuild

* Sat Jan 04 2020 luigiwalser <luigiwalser> 1:2.49.92-3.mga8
+ Revision: 1475939
- rebuild for readline

* Sat Sep 22 2018 umeabot <umeabot> 1:2.49.92-2.mga7
+ Revision: 1296584
- Mageia 7 Mass Rebuild

* Sat Aug 18 2018 wally <wally> 1:2.49.92-1.mga7
+ Revision: 1252532
- new version 2.49.92
- sync patches and .spec with Fedora
+ luigiwalser <luigiwalser>
- rebuild for gdbm

* Sun Jan 21 2018 wally <wally> 1:2.49-18.mga7
+ Revision: 1195531
- add patch from upstream to fix build with new readline
- rebuild for new readline

* Sat Jul 01 2017 akien <akien> 1:2.49-17.mga6
+ Revision: 1108903
- Rebuild for libffcall

* Sun Mar 12 2017 neoclust <neoclust> 1:2.49-16.mga6
+ Revision: 1092132
- Rebuild for armv7

* Thu May 12 2016 tv <tv> 1:2.49-15.mga6
+ Revision: 1014149
- use std build macros; prevent commented out macros to break build

* Sat Feb 13 2016 umeabot <umeabot> 1:2.49-14.mga6
+ Revision: 959729
- Mageia 6 Mass Rebuild

* Thu Feb 11 2016 pterjan <pterjan> 1:2.49-13.mga6
+ Revision: 955981
- Add some patches from fedora, especially one for gcc5
+ umeabot <umeabot>
- Mageia 6 Mass Rebuild

* Tue Nov 25 2014 cjw <cjw> 1:2.49-11.mga5
+ Revision: 799005
- rebuild against postgresql9.4

* Wed Oct 15 2014 umeabot <umeabot> 1:2.49-10.mga5
+ Revision: 745103
- Second Mageia 5 Mass Rebuild

* Thu Sep 18 2014 umeabot <umeabot> 1:2.49-9.mga5
+ Revision: 693622
- Rebuild to fix library dependencies

* Tue Sep 16 2014 umeabot <umeabot> 1:2.49-8.mga5
+ Revision: 678428
- Mageia 5 Mass Rebuild

* Sat Oct 19 2013 umeabot <umeabot> 1:2.49-7.mga4
+ Revision: 526005
- Mageia 4 Mass Rebuild

* Sun Jun 02 2013 kamil <kamil> 1:2.49-6.mga4
+ Revision: 435475
- rebuild for Mageia4

* Fri Jan 11 2013 dmorgan <dmorgan> 1:2.49-5.mga3
+ Revision: 348735
- Use a more complete P1 to fix build ( from fedora )
+ umeabot <umeabot>
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Sun Dec 02 2012 kamil <kamil> 1:2.49-4.mga3
+ Revision: 325088
- add pkgconfig(ncursesw) as BR
- add clisp-2.49-mga-fix-importing-ipc-headers.patch to fix build
- clean .spec a bit
+ fwang <fwang>
- add fedora patch to build with gcc 4.7

* Tue Dec 06 2011 fwang <fwang> 1:2.49-4.mga2
+ Revision: 177155
- rebuild for new gdbm

* Wed Sep 14 2011 fwang <fwang> 1:2.49-3.mga2
+ Revision: 143186
- add back libdir
- cleanup br

* Tue Mar 01 2011 dmorgan <dmorgan> 1:2.49-2.mga1
+ Revision: 62112
- Build with readline

* Tue Mar 01 2011 dmorgan <dmorgan> 1:2.49-1.mga1
+ Revision: 62091
- Fix build
- imported package clisp


* Fri Aug 06 2010 Paulo Andrade <pcpa@mandriva.com.br> 1:2.49-1mdv2011.0
+ Revision: 567191
- Update to version 2.49

* Wed Aug 19 2009 Paulo Andrade <pcpa@mandriva.com.br> 1:2.48-2mdv2010.0
+ Revision: 418280
- Make the -I option completely ignore readline
  # This is an at least "somewhat" elegant version of an alternate ugly hack
  # required to make sagemath python-pexpect interface work correctly with
  # clisp

* Wed Jul 29 2009 Frederik Himpe <fhimpe@mandriva.org> 1:2.48-1mdv2010.0
+ Revision: 404036
- Update to new version 2.48
- Sync configure options and BuildRequires with Fedora (more
  modules are available now)

* Sat Feb 28 2009 Guillaume Rousse <guillomovitch@mandriva.org> 1:2.47-2mdv2009.1
+ Revision: 346030
- rebuild against new readline

* Tue Nov 11 2008 Frederik Himpe <fhimpe@mandriva.org> 1:2.47-1mdv2009.1
+ Revision: 302178
- Update to new version 2.47
- Remove patch fixing postgresql detection, integrated upstream
- Specifically buildrequire version 4.6 of berkeleydb, it does not
  build with db 4.7

* Wed Aug 13 2008 Frederik Himpe <fhimpe@mandriva.org> 1:2.46-1mdv2009.0
+ Revision: 271576
- Update to new version 2.46

* Thu Aug 07 2008 Thierry Vignaud <tv@mandriva.org> 1:2.45-2mdv2009.0
+ Revision: 266536
- rebuild early 2009.0 package (before pixel changes)

* Tue Jun 10 2008 Frederik Himpe <fhimpe@mandriva.org> 1:2.45-1mdv2009.0
+ Revision: 217754
- New version 2.45
- Remove postgresql patch, it is included upstream. Replace it by new pgsql
  patch because upstream configure script has an error finding the headers
- Remove topdir patch: install it in versioned lib directory, like upstream,
  Fedora and Debian are doing
- Needs bigger stack size to succeed in building
- Small Adaptatations to make it build in directory named build
- Build gtk2 module

* Tue Feb 26 2008 Frederik Himpe <fhimpe@mandriva.org> 1:2.44.1-1mdv2008.1
+ Revision: 175504
- New upstream bugfix release

* Wed Feb 13 2008 Frederik Himpe <fhimpe@mandriva.org> 1:2.44-1mdv2008.1
+ Revision: 167118
- New upstream release
- Add libffcall-devel BuildRequires

* Mon Jan 07 2008 Pascal Terjan <pterjan@mandriva.org> 1:2.43-2mdv2008.1
+ Revision: 146277
- Make the -devel installable

* Mon Dec 31 2007 Oden Eriksson <oeriksson@mandriva.com> 1:2.43-1mdv2008.1
+ Revision: 139851
- 2.43

* Thu Dec 27 2007 Oden Eriksson <oeriksson@mandriva.com> 1:2.41a-2mdv2008.1
+ Revision: 138227
- build against db4.2-devel for now
- rebuilt against bdb 4.6.x libs

  + Thierry Vignaud <tv@mandriva.org>
    - kill re-definition of %%buildroot on Pixel's request

* Thu May 31 2007 Per Øyvind Karlsen <peroyvind@mandriva.org> 1:2.41a-1mdv2008.0
+ Revision: 33431
- fix buildrequires
- remove icon
- 2.41a
- add url for source
- update to 2.41 (with help from Frederik Himpe)
- fix detection of postgresql headers (P0 from Frederik)
- Import clisp



* Mon Sep 18 2006 Gwenole Beauchesne <gbeauchesne@mandriva.com> 1:2.38-2mdv2007.0
- Rebuild

* Sat May 20 2006 Per Øyvind Karlsen <pkarlsen@mandriva.com> 2.38-1mdk
- 2.38
- sort out some build issues with flags etc
- build with dynamic modules support
- build against libsigsegv
- lib64 fix
- fix buildrequires
- %%mkrel
- move check to new %%check stage

* Sat Dec 31 2005 Mandriva Linux Team <http://www.mandrivaexpert.com/> 2.33.2-3mdk
- Rebuild

* Thu Jan 20 2005 Per Øyvind Karlsen <peroyvind@linux-mandrake.com> 2.33.2-2mdk
- rebuild for new readline

* Sat Jun 05 2004 Per ?yvind Karlsen <peroyvind@linux-mandrake.com> 2.33.2-1mdk
- 2.33.2
- drop P0

* Sat Apr 17 2004 Per Øyvind Karlsen <peroyvind@linux-mandrake.com> 2.33-2mdk
- fix buildrequires

* Fri Apr 02 2004 Per Øyvind Karlsen <peroyvind@linux-mandrake.com> 2.33-1mdk
- 2.33
- clean docs
- update P0 from debian
- minor fixes
- disable parallell build

* Mon Jun 23 2003 Per Øyvind Karlsen <peroyvind@sintrax.net> 2.30-2mdk
- fix prefix etc. (from Mark Draheim <rickscafe.casablanca@gmx.net>)
- fix %%files list

* Tue Jun 17 2003 Per Øyvind Karlsen <peroyvind@sintrax.net> 2.30-1mdk
- 2.30
- cleanups
- P0 from debian, dropped alpha patch
- alot of spec file fixes

* Tue Jul 17 2001 Daouda LO <daouda@mandrakesoft.com> 2.27-1mdk
- release 2.27
  o The default extension of Lisp source files for CLISP is now ".lisp"
    instead of ".lsp". When both "foo.lisp" and "foo.lsp" exist, 
    (LOAD "foo") will load "foo.lisp".

  o Changed bytecode format. All .fas files generated by previous CLISP
     versions  are invalid and must be recompiled.
  o More Ansi CL compliances  
  o See more of the changelog: http://sourceforge.net/forum/forum.php?forum_id=72006 

- update URL.  
- new versioning scheme.
- merge ppc build.
- s|config.lsp|config.lisp| in ppc build.

* Wed Apr 25 2001 Geoffrey Lee <snailtalk@mandrakesoft.com> 2000.03.06-4mdk
- Make it build on the Alpha platform.
- Quiet output when uncompressing the source because it is really too annoying
  to watch.

* Sun Nov 05 2000 David BAUDENS <baudens@mandrakesoft.com> 2000.03.06-3mdk
- Rewrite spec following Clisp Install documentation to be able to build this
  package on all archs
- Have an intelligent description

* Sun Jul 23 2000 Pixel <pixel@mandrakesoft.com> 2000.03.06-2mdk
- *much* cleanup, macorizaiton, BM

* Mon Apr  3 2000 Adam Lebsack <adam@mandrakesoft.com> 2000.03.06-1mdk
- Update to 2000.03.06

* Tue Feb 22 2000 Stefan van der Eijk <s.vandereijk@chello.nl>
- rewrote most of .spec file
- updated to 1999.07.22
